==> ozone-1.4.0-src.tar.gz: ozone-1.4.0-src/hadoop-ozone/recon/src/main/java/org/apache/hadoop/ozone/recon/api/types/KeysResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.ozone.recon.api.types;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.Collection;

/**
 * Class that represents the API Response structure of Keys within a container.
 */
public class KeysResponse {
  /**
   * Total count of the keys.
   */
  @JsonProperty("totalCount")
  private long totalCount;

  /**
   * An array of keys.
   */
  @JsonProperty("keys")
  private Collection<KeyMetadata> keys;

  public KeysResponse(long totalCount, Collection<KeyMetadata> keys) {
    this.totalCount = totalCount;
    this.keys = keys;
  }

  public long getTotalCount() {
    return totalCount;
  }

  public Collection<KeyMetadata> getKeys() {
    return keys;
  }
}

==> ozone-1.4.1-src.tar.gz: ozone-1.4.1-src/hadoop-ozone/recon/src/main/java/org/apache/hadoop/ozone/recon/api/types/KeysResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.ozone.recon.api.types;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.Collection;

/**
 * Class that represents the API Response structure of Keys within a container.
 */
public class KeysResponse {
  /**
   * Total count of the keys.
   */
  @JsonProperty("totalCount")
  private long totalCount;

  /**
   * An array of keys.
   */
  @JsonProperty("keys")
  private Collection<KeyMetadata> keys;

  @JsonProperty("lastKey")
  private String lastKey;

  public KeysResponse(long totalCount, Collection<KeyMetadata> keys, String lastKey) {
    this.totalCount = totalCount;
    this.keys = keys;
    this.lastKey = lastKey;
  }

  public long getTotalCount() {
    return totalCount;
  }

  public Collection<KeyMetadata> getKeys() {
    return keys;
  }
  public String getLastKey() {
    return lastKey;
  }
}
